<?php 
/**
 *  @Name:			nsYoutubeFeedParser
 *  @URI:			http://www.nsauditor.com/wordpress/youtube-video-feed-widget/
 *  @Description:	Youtube Feed Parser Classes
 *  @Version:		1.0
 *  @Author:		Varuzhan Kankanyan
 *  @Copyright:		(c) 2012 - NSASOFT US, LLC.
 *  @License:		GPLv2 or upper	
 *  @Created:		11/29/2012 
 */
class nsYoutubeFeedNode
{
  // Public Properties
  Public $id = "";
  Public $title = "";
  Public $link = "";
  Public $description = "";
  Public $pubDate = "";

  // Constructor
  function __construct()
  {
	$this->id = "";
    $this->title = "";
    $this->link = "";
	$this->description = "";
	$this->pubDate = "";
  }

  // Destructor
  function __destruct()
  {
  }
}

class nsYoutubeFeedParser 
{
	// Private Properties
	private $youtube_name = '';
	private $count = 0;
	private $xml;
	
	// Constructor
	function __construct($yname)
	{
		$this->youtube_name = $yname;
		$this->count = 0;
	}
	
	// Destructor
	function __destruct()
	{
	}	
	
	
	private function text2SentenceArray($text)
	{
		return preg_split('/(?<=[.?!])\s+(?=[a-z])/i', $text);
	}	
	
	private function substr_sentence($string, $limit=10, $max_char = 400)	
	{
		$sentences = $this->text2SentenceArray($string);
		$rerult_str='';
		for($i=0;$i<$limit;$i++)
		{
			if((strlen($rerult_str)+strlen($sentences[$i]))<=$max_char)
				$rerult_str .=$sentences[$i];
			else return $rerult_str;	
		}
		
		return $rerult_str;
	}

	// Public Methods	
	
	// Load RSS data from URL
	// format http://gdata.youtube.com/feeds/api/users/nsasoft/uploads?orderby=viewCount&q=software&max-results=20
	public function parseYoutubeFeed($orderby='viewCount',$maxfeeds=25,$query='')
	{
		if($this->youtube_name=='')
			$url = "http://gdata.youtube.com/feeds/api/videos";	
		else	
			$url = "http://gdata.youtube.com/feeds/api/users/$this->youtube_name/uploads";
			
		$url = $this->compose_feed_url($url,$orderby,$maxfeeds,$query);
		//echo $url.'<br>';
		$this->xml = simplexml_load_file($url);		
		$this->count = count($this->xml->entry);
		
		return 	$this->count;
	}
	
	public function compose_feed_url($feedURL,$orderby='viewCount',$maxfeeds=25,$query='') 
	{        
		if (!in_array($orderby,array("relevance","published","viewCount","rating"))) $orderby="viewCount";
		$feedURL.="?orderby=$orderby";        
		$feedURL.="&max-results=$maxfeeds";
		if (!empty($query)) $feedURL.="&q=$query";
		return $feedURL;
	}	
	
	// Get Rss Entry info
	public function getYFeedEntry(&$nsYoutubeFeedNode,$i,$nsentences=10,$ntextsize=400,$bshow_separators=TRUE)
	{
		try{		
			if($i>$this->count) throw new Exception("Index number exceeds the number of feeds!");			
		}catch(Exception $e)		
			{
				echo "Error: ".$e->getMessage()." On Line: ".$e->getLine()." File: ".$e->getFile()."<br>";
				return FALSE;
			}			
		$id = $this->xml->entry[$i]->id;
		$id = str_replace("http://gdata.youtube.com/feeds/api/videos/","",$id);
		$title = $this->xml->entry[$i]->title;
		$link = 'http://www.youtube.com/watch?v='.$id;
		$description = $this->xml->entry[$i]->content;
		$pubDate = $this->xml->entry[$i]->updated;
		$time = strtotime($pubDate); // Convert the time
		$date_in_your_format = date("D, j M Y \ G:i:s", $time);
		$subdesc = $this->substr_sentence($description,$nsentences,$ntextsize);

		if($bshow_separators){
			$subdesc = nl2br($subdesc);
		}	
		
		$nsYoutubeFeedNode->id = "http://www.youtube.com/embed/$id";		
		$nsYoutubeFeedNode->title = $title;
		$nsYoutubeFeedNode->link = $link;
		$nsYoutubeFeedNode->description = $subdesc;
		$nsYoutubeFeedNode->pubDate = $date_in_your_format;
		
		return TRUE;

	}
}		